@@ -1226,6 +1226,152 @@ duration_as_double_cpp(cpp11::list_of<cpp11::integers> fields,
 
 // -----------------------------------------------------------------------------
 
+template <class ClockDuration>
+static
+inline
+cpp11::writable::list
+duration_abs_impl(const ClockDuration& x) {
+  using Duration = typename ClockDuration::duration;
+  using Rep = typename Duration::rep;
+
+  const r_ssize size = x.size();
+  ClockDuration out(size);
+
+  const Rep zero{0};
+
+  for (r_ssize i = 0; i < size; ++i) {
+    if (x.is_na(i)) {
+      out.assign_na(i);
+      continue;
+    }
+
+    const Duration elt = x[i];
+    const Rep elt_rep = elt.count();
+    const Rep out_rep = (elt_rep < zero) ? std::abs(elt_rep) : elt_rep;
+    const Duration out_elt{out_rep};
+
+    out.assign(out_elt, i);
+  }
+
+  return out.to_list();
+}
+
+[[cpp11::register]]
+cpp11::writable::list
+duration_abs_cpp(cpp11::list_of<cpp11::integers> fields,
+                 const cpp11::integers& precision_int) {
+  using namespace rclock;
+
+  cpp11::integers ticks = duration::get_ticks(fields);
+  cpp11::integers ticks_of_day = duration::get_ticks_of_day(fields);
+  cpp11::integers ticks_of_second = duration::get_ticks_of_second(fields);
+
+  duration::years dy{ticks};
+  duration::quarters dq{ticks};
+  duration::months dm{ticks};
+  duration::weeks dw{ticks};
+  duration::days dd{ticks};
+  duration::hours dh{ticks, ticks_of_day};
+  duration::minutes dmin{ticks, ticks_of_day};
+  duration::seconds ds{ticks, ticks_of_day};
+  duration::milliseconds dmilli{ticks, ticks_of_day, ticks_of_second};
+  duration::microseconds dmicro{ticks, ticks_of_day, ticks_of_second};
+  duration::nanoseconds dnano{ticks, ticks_of_day, ticks_of_second};
+
+  switch (parse_precision(precision_int)) {
+  case precision::year: return duration_abs_impl(dy);
+  case precision::quarter: return duration_abs_impl(dq);
+  case precision::month: return duration_abs_impl(dm);
+  case precision::week: return duration_abs_impl(dw);
+  case precision::day: return duration_abs_impl(dd);
+  case precision::hour: return duration_abs_impl(dh);
+  case precision::minute: return duration_abs_impl(dmin);
+  case precision::second: return duration_abs_impl(ds);
+  case precision::millisecond: return duration_abs_impl(dmilli);
+  case precision::microsecond: return duration_abs_impl(dmicro);
+  case precision::nanosecond: return duration_abs_impl(dnano);
+  }
+
+  never_reached("duration_abs_cpp");
+}
+
+// -----------------------------------------------------------------------------
+
+template <class ClockDuration>
+static
+inline
+cpp11::writable::integers
+duration_sign_impl(const ClockDuration& x) {
+  using Duration = typename ClockDuration::duration;
+  using Rep = typename Duration::rep;
+
+  const r_ssize size = x.size();
+  cpp11::writable::integers out(size);
+
+  const Rep zero{0};
+
+  for (r_ssize i = 0; i < size; ++i) {
+    if (x.is_na(i)) {
+      out[i] = r_int_na;
+      continue;
+    }
+
+    const Duration elt = x[i];
+    const Rep elt_rep = elt.count();
+
+    if (elt_rep == zero) {
+      out[i] = 0;
+    } else if (elt_rep > zero) {
+      out[i] = 1;
+    } else {
+      out[i] = -1;
+    }
+  }
+
+  return out;
+}
+
+[[cpp11::register]]
+cpp11::writable::integers
+duration_sign_cpp(cpp11::list_of<cpp11::integers> fields,
+                  const cpp11::integers& precision_int) {
+  using namespace rclock;
+
+  cpp11::integers ticks = duration::get_ticks(fields);
+  cpp11::integers ticks_of_day = duration::get_ticks_of_day(fields);
+  cpp11::integers ticks_of_second = duration::get_ticks_of_second(fields);
+
+  duration::years dy{ticks};
+  duration::quarters dq{ticks};
+  duration::months dm{ticks};
+  duration::weeks dw{ticks};
+  duration::days dd{ticks};
+  duration::hours dh{ticks, ticks_of_day};
+  duration::minutes dmin{ticks, ticks_of_day};
+  duration::seconds ds{ticks, ticks_of_day};
+  duration::milliseconds dmilli{ticks, ticks_of_day, ticks_of_second};
+  duration::microseconds dmicro{ticks, ticks_of_day, ticks_of_second};
+  duration::nanoseconds dnano{ticks, ticks_of_day, ticks_of_second};
+
+  switch (parse_precision(precision_int)) {
+  case precision::year: return duration_sign_impl(dy);
+  case precision::quarter: return duration_sign_impl(dq);
+  case precision::month: return duration_sign_impl(dm);
+  case precision::week: return duration_sign_impl(dw);
+  case precision::day: return duration_sign_impl(dd);
+  case precision::hour: return duration_sign_impl(dh);
+  case precision::minute: return duration_sign_impl(dmin);
+  case precision::second: return duration_sign_impl(ds);
+  case precision::millisecond: return duration_sign_impl(dmilli);
+  case precision::microsecond: return duration_sign_impl(dmicro);
+  case precision::nanosecond: return duration_sign_impl(dnano);
+  }
+
+  never_reached("duration_sign_impl");
+}
+
+// -----------------------------------------------------------------------------
+
 template <class ClockDuration>
 static
 inline
